@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "go-template-mode" "1.0.0"
+(define-package "go-template-mode" "20260102.1442"
   "Major mode for Go templates."
   '((emacs "28.1"))
   :url "https://codeberg.org/rch/go-template-mode"
